/*
    Copyright (C) 2000  Andy Sherwood   (enigmax@home.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// Folder.cpp : Implementation of CFolder
#include "stdafx.h"
#include "Rio500Remix.h"
#include "Folder.h"

/////////////////////////////////////////////////////////////////////////////
// CFolder

//*********************************************************************************************
// Description: Constructor for CFolder
//
// Returns:     Nothing
//
//*********************************************************************************************
CFolder::CFolder()
 :  m_lNumber(-1),      // Folder number
    m_wBitmapBlocks(0)  // Bitmap blocks
{
}

//*********************************************************************************************
// Description: Get folder number (starts at 0)
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::get_Number(
    long *pVal) // [o] Folder number
{
    *pVal = m_lNumber;
    return S_OK;
}

//*********************************************************************************************
// Description: Put folder number
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::put_Number(
    long newVal)    // [i] Folder number
{
    m_lNumber = newVal;
    return S_OK;
}

//*********************************************************************************************
// Description: Get folder name
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::get_Name(
    BSTR *pVal) // [o] Folder name
{
    *pVal = m_bsName.copy();
    return S_OK;
}

//*********************************************************************************************
// Description: Put folder name
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::put_Name(
    BSTR newVal)    // [i] Folder name
{
    m_bsName = newVal;
    return S_OK;
}

//*********************************************************************************************
// Description: Get bitmap as variant.  Variant contains a SAFEARRAY of 1536 VT_UI1 elements
//              which constitute a 786x16x1bpp bitmap
//
// Returns:     Same as VariantCopy
//
//*********************************************************************************************
STDMETHODIMP CFolder::get_Bitmap(
    VARIANT *pVal)  // [o] A variant containing a 1536 VT_UI1 element SAFEARRAY
{
    return VariantCopy(pVal, &m_vBitmap);
}

//*********************************************************************************************
// Description: Put bitmap as variant.  See description above.
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::put_Bitmap(
    VARIANT newVal) // [i] A variant containing a 1536 VT_UI1 element SAFEARRAY
{
    m_vBitmap = newVal;
    return S_OK;
}

//*********************************************************************************************
// Description: Get number of bitmap blocks.  A block is an 8x16 rectangle of pixels in the
//              bitmap.  The Rio will scroll only the portion of the song/folder name 
//              represented by these blocks, not the entire 768 pixel name
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::get_BitmapBlocks(
    WORD *pVal) // [o] Number of bitmap blocks
{
    *pVal = m_wBitmapBlocks;
    return S_OK;
}

//*********************************************************************************************
// Description: Put number of bitmap blocks.  See description above.
//
// Returns:     S_OK
//
//*********************************************************************************************
STDMETHODIMP CFolder::put_BitmapBlocks(
    WORD newVal)    // [i] Number of bitmap blocks
{
    m_wBitmapBlocks = newVal;
    return S_OK;
}

